@@ -2,8 +2,9 @@ package MooseX::Log::Log4perl;
 
 use Moose::Role;
 use Log::Log4perl;
+use Data::Dumper;
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 has 'logger' => (
 	is      => 'rw',
@@ -12,6 +13,24 @@ has 'logger' => (
 	default => sub { my $self = shift; return Log::Log4perl->get_logger($self) }
 );
 
+#sub BUILD {
+#	my $pkg = shift;
+#
+#    return if $pkg eq 'main';
+#
+#    ( $pkg->can('meta') && ($pkg->meta->isa('Moose::Meta::Class')||$pkg->meta->isa('Moose::Meta::Role')) )
+#      || confess "This package can only be used in Moose based classes";
+#
+#	foreach my $lvl (qw(fatal error warn info debug trace)) {
+#		$pkg->meta->add_method("log_$lvl" => sub {
+#			my $self = shift;
+#			$self->logger->$lvl(@_);
+#		});
+#    	
+#	}
+#	print STDERR "Build\n";
+#}
+
 sub log {
 	my ( $self, $category ) = @_;
 	if (defined($category)) {
@@ -37,13 +56,13 @@ This document describes MooseX::Log::Log4perl version 0.1
  package MyApp;
  use Moose;
  use Log::Log4perl qw(:easy);
-
+ 
  with MooseX::Log::Log4perl;
-
+ 
  BEGIN {
- 	Log::Log4perl->easy_init();
+   Log::Log4perl->easy_init();
  }
-
+ 
  sub foo {
    my ($self) = @_;
    $self->log->debug("started bar");    ### logs with default class catergory "MyApp"
@@ -57,12 +76,26 @@ A logging role building a very lightweight wrapper to L<Log::Log4perl> for use w
 The initialization of the Log4perl instance must be performed prior to logging the first log message.
 Otherwise the default initialization will happen, probably not doing the things you expect.
 
+For compatibility the C<logger> attribute can be accessed to use a common interface for application logging.
+
 =head1 ACCESSORS
 
 =head2 logger
 
-This is the main L<Log::Log4perl> object that does all the work. It
-has methods for each of the log levels, such as C<debug> or C<error>.
+The C<logger> attribute holds the L<Log::Log4perl> object that implements all logging methods for the
+defined log levels, such as C<debug> or C<error>. As this method is defined also in other logging 
+roles/systems like L<MooseX::Log::LogDispatch> this can be thought of as a common logging interface.
+
+  package MyApp::View::JSON;
+  
+  extends 'MyApp::View';
+  with 'MooseX:Log::Log4perl';
+  
+  sub bar {
+    $self->logger->debug("Something could be crappy here");	# logs a debug message
+    $self->logger->debug("Something could be crappy here");	# logs a debug message
+  }
+  
 
 =head2 log
 
@@ -77,7 +110,7 @@ this method call.
 
 =head1 SEE ALSO
 
- L<Log::Log4perl>, L<Moose>, L<MooseX::LogDispatch>, L<Moose>
+L<Log::Log4perl>, L<Moose>, L<MooseX::LogDispatch>
 
 =head1 BUGS AND LIMITATIONS
 
@@ -94,9 +127,11 @@ Roland Lammel C<< <lammel@cpan.org> >>
 Inspired by the work by Chris Prather C<< <perigrin@cpan.org> >> and Ash
 Berlin C<< <ash@cpan.org> >> on L<MooseX::LogDispatch>
 
+Thanks to Michael Schilli C<< <m@perlmeister.com> >> for L<Log::Log4perl> and suggestions in the interface.
+
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, Roland Lammel C<< <lammel@cpan.org> >>. Some rights reserved.
+Copyright (c) 2008, Roland Lammel C<< <lammel@cpan.org> >>. Some rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
